/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "HTMLTableCellElement.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/GdomHTMLTableCellElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateGdomHTMLTableCellElement.h"
#include "gdom/PrivateIntGdomHTMLTableCellElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLTableCellElement::GDOMHTMLTableCellElement(PassRefPtr<WebCore::HTMLTableCellElement> impl)
    : GDOMHTMLElement(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLTableCellElement.h"
#include <gdom/GdomHTMLTableCellElement.h>
#include <gdom/PrivateGdomHTMLTableCellElement.h>
#include <gdom/PrivateIntGdomHTMLTableCellElement.h>
#include <gdom/GdomHTMLTableCellElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLTableCellElement, gdom_html_table_cell_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLTableCellElementPrivate {
    class WebCore::HTMLTableCellElement *item;
};

#define GDOM_HTML_TABLE_CELL_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_TABLE_CELL_ELEMENT, GdomHTMLTableCellElementPrivate))
*/
G_END_DECLS
WebCore::HTMLTableCellElement *
gdom_html_table_cell_element_get_private(GdomHTMLTableCellElement *request)
{
    GDOMHTMLTableCellElement *res;
    res = static_cast<GDOMHTMLTableCellElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLTableCellElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_CELL_INDEX,
    PROP_ABBR,
    PROP_ALIGN,
    PROP_AXIS,
    PROP_BG_COLOR,
    PROP_CH,
    PROP_CH_OFF,
    PROP_COL_SPAN,
    PROP_HEADERS,
    PROP_HEIGHT,
    PROP_NO_WRAP,
    PROP_ROW_SPAN,
    PROP_SCOPE,
    PROP_V_ALIGN,
    PROP_WIDTH,
};


static void gdom_html_table_cell_element_finalize(GObject* object)
{
    /*GdomHTMLTableCellElement* request = GDOM_HTML_TABLE_CELL_ELEMENT(object);*/
    /*GdomHTMLTableCellElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_table_cell_element_parent_class)->finalize(object);
}

static void gdom_html_table_cell_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLTableCellElement *self = GDOM_HTML_TABLE_CELL_ELEMENT(object);
    WebCore::HTMLTableCellElement * gself = (gdom_html_table_cell_element_get_private(self));
    switch (prop_id) {
     case PROP_ABBR:
    {
         gself->setAbbr(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_ALIGN:
    {
         gself->setAlign(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_AXIS:
    {
         gself->setAxis(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_BG_COLOR:
    {
         gself->setBgColor(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CH:
    {
         gself->setCh(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CH_OFF:
    {
         gself->setChOff(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_COL_SPAN:
    {
         gself->setColSpan((g_value_get_long (value)) );
         break;
    }
     case PROP_HEADERS:
    {
         gself->setHeaders(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_HEIGHT:
    {
         gself->setHeight(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_NO_WRAP:
    {
         gself->setNoWrap((g_value_get_boolean (value)) );
         break;
    }
     case PROP_ROW_SPAN:
    {
         gself->setRowSpan((g_value_get_long (value)) );
         break;
    }
     case PROP_SCOPE:
    {
         gself->setScope(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_V_ALIGN:
    {
         gself->setVAlign(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_WIDTH:
    {
         gself->setWidth(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_table_cell_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLTableCellElement *self = GDOM_HTML_TABLE_CELL_ELEMENT(object);
    WebCore::HTMLTableCellElement * gself = (gdom_html_table_cell_element_get_private(self));
    switch (prop_id) {
    case PROP_CELL_INDEX:
    {
         g_value_set_long (value, gself->cellIndex());
         break;
    }
    case PROP_ABBR:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->abbr()));
         break;
    }
    case PROP_ALIGN:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->align()));
         break;
    }
    case PROP_AXIS:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->axis()));
         break;
    }
    case PROP_BG_COLOR:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->bgColor()));
         break;
    }
    case PROP_CH:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->ch()));
         break;
    }
    case PROP_CH_OFF:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->chOff()));
         break;
    }
    case PROP_COL_SPAN:
    {
         g_value_set_long (value, gself->colSpan());
         break;
    }
    case PROP_HEADERS:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->headers()));
         break;
    }
    case PROP_HEIGHT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->height()));
         break;
    }
    case PROP_NO_WRAP:
    {
         g_value_set_boolean (value, gself->noWrap());
         break;
    }
    case PROP_ROW_SPAN:
    {
         g_value_set_long (value, gself->rowSpan());
         break;
    }
    case PROP_SCOPE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->scope()));
         break;
    }
    case PROP_V_ALIGN:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->vAlign()));
         break;
    }
    case PROP_WIDTH:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->width()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_table_cell_element_class_init(GdomHTMLTableCellElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_table_cell_element_finalize;
    g_klass->set_property = gdom_html_table_cell_element__set_property_fn;
    g_klass->get_property = gdom_html_table_cell_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_CELL_INDEX,
            g_param_spec_long ("cell_index", /* name */
                "html_table_cell_element_cell_index", /* short description */
                "read-only  glong HTMLTableCellElement.cell_index", /* longer - could do with some extra doc stuff here */
                 G_MINLONG,        /* min */
                G_MAXLONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_ABBR,
            g_param_spec_string ("abbr", /* name */
                "html_table_cell_element_abbr", /* short description */
                "read-write  gchar * HTMLTableCellElement.abbr", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_ALIGN,
            g_param_spec_string ("align", /* name */
                "html_table_cell_element_align", /* short description */
                "read-write  gchar * HTMLTableCellElement.align", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_AXIS,
            g_param_spec_string ("axis", /* name */
                "html_table_cell_element_axis", /* short description */
                "read-write  gchar * HTMLTableCellElement.axis", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_BG_COLOR,
            g_param_spec_string ("bg_color", /* name */
                "html_table_cell_element_bg_color", /* short description */
                "read-write  gchar * HTMLTableCellElement.bg_color", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CH,
            g_param_spec_string ("ch", /* name */
                "html_table_cell_element_ch", /* short description */
                "read-write  gchar * HTMLTableCellElement.ch", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CH_OFF,
            g_param_spec_string ("ch_off", /* name */
                "html_table_cell_element_ch_off", /* short description */
                "read-write  gchar * HTMLTableCellElement.ch_off", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_COL_SPAN,
            g_param_spec_long ("col_span", /* name */
                "html_table_cell_element_col_span", /* short description */
                "read-write  glong HTMLTableCellElement.col_span", /* longer - could do with some extra doc stuff here */
                 G_MINLONG,        /* min */
                G_MAXLONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HEADERS,
            g_param_spec_string ("headers", /* name */
                "html_table_cell_element_headers", /* short description */
                "read-write  gchar * HTMLTableCellElement.headers", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HEIGHT,
            g_param_spec_string ("height", /* name */
                "html_table_cell_element_height", /* short description */
                "read-write  gchar * HTMLTableCellElement.height", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_NO_WRAP,
            g_param_spec_boolean ("no_wrap", /* name */
                "html_table_cell_element_no_wrap", /* short description */
                "read-write  gboolean HTMLTableCellElement.no_wrap", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_ROW_SPAN,
            g_param_spec_long ("row_span", /* name */
                "html_table_cell_element_row_span", /* short description */
                "read-write  glong HTMLTableCellElement.row_span", /* longer - could do with some extra doc stuff here */
                 G_MINLONG,        /* min */
                G_MAXLONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_SCOPE,
            g_param_spec_string ("scope", /* name */
                "html_table_cell_element_scope", /* short description */
                "read-write  gchar * HTMLTableCellElement.scope", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_V_ALIGN,
            g_param_spec_string ("v_align", /* name */
                "html_table_cell_element_v_align", /* short description */
                "read-write  gchar * HTMLTableCellElement.v_align", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_WIDTH,
            g_param_spec_string ("width", /* name */
                "html_table_cell_element_width", /* short description */
                "read-write  gchar * HTMLTableCellElement.width", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLTableCellElementPrivate));*/
}

static void gdom_html_table_cell_element_init(GdomHTMLTableCellElement* request)
{
    /*GdomHTMLTableCellElementPrivate* priv = GDOM_HTML_TABLE_CELL_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

